@@ -8,19 +8,21 @@ class JSONSchemaDraftsParentBuilder(JSONSchemaBuilder):
     output_file_name = ["draft-parent-record-schema", "file"]
     parent_module_root_name = "jsonschemas"
 
-    def target_json(self):
+    def builtin_json(self):
         return {
-            "$schema": "http://json-schema.org/draft-07/schema#",
-            # "$id": f"{schema.current_model.schema_server}{schema.current_model.drafts_parent_schema_name}",
-            "$id": "local://parent-v1.0.0.json",
             "type": "object",
-            "properties": {"id": {"type": "keyword"}},
+            "properties": {
+                "$schema": {"type": "keyword"},
+                "created": {"type": "datetime"},
+                "id": {"type": "keyword"},
+                "updated": {"type": "datetime"},
+            },
         }
 
     def build_node(self, node):
         from oarepo_model_builder.datatypes import datatypes
 
-        json = self.target_json()
+        json = self.builtin_json()
         parsed_section = datatypes.get_datatype(
             parent=None,
             data=json,
@@ -34,5 +36,5 @@ class JSONSchemaDraftsParentBuilder(JSONSchemaBuilder):
         )
         if skip:
             return
-        generated = self.generate(node)
+        generated = self.generate(parsed_section)
         self.output.merge(generated)
