@@ -11,6 +11,7 @@ from .draft_model import (
     DraftServiceModelComponent,
 )
 from .draft_tests import DraftModelTestComponent
+from .published_service import PublishedServiceComponent
 
 DRAFT_COMPONENTS = [
     DraftParentComponent,
@@ -24,4 +25,5 @@ DRAFT_COMPONENTS = [
     DraftMappingModelComponent,
     DraftResourceModelComponent,
     DraftServiceModelComponent,
+    PublishedServiceComponent,
 ]
