@@ -11,3 +11,6 @@ class InvenioDraftsSetupCfgBuilder(OutputBuilder):
         output: CFGOutput = self.builder.get_output("cfg", "setup.cfg")
 
         output.add_dependency("invenio-drafts-resources", ">=1.0.4")
+
+        if not self.current_model.definition["published-service"].get("skip"):
+            output.add_dependency("oarepo-published-service", ">=1.0.0")
